@@ -53,8 +53,11 @@ Helper::Helper(KSharedConfig::Ptr config, QObject *parent)
 {
     if (qApp) {
         connect(qApp, &QApplication::paletteChanged, this, [=]() {
-            if (qApp->property("KDE_COLOR_SCHEME_PATH").isValid()) {
-                const auto path = qApp->property("KDE_COLOR_SCHEME_PATH").toString();
+            if (!qApp->property("KDE_COLOR_SCHEME_PATH").isValid()) {
+                return;
+            }
+            const auto path = qApp->property("KDE_COLOR_SCHEME_PATH").toString();
+            if (!path.isEmpty()) {
                 KConfig config(path, KConfig::SimpleConfig);
                 KConfigGroup group(config.group("WM"));
                 const QPalette palette(QApplication::palette());
@@ -95,17 +98,20 @@ void Helper::loadConfig()
     _cachedAutoValid = false;
     _decorationConfig->load();
 
-    KConfig config(qApp->property("KDE_COLOR_SCHEME_PATH").toString(), KConfig::SimpleConfig);
-    KConfigGroup appGroup(config.group("WM"));
     KConfigGroup globalGroup(_config->group("WM"));
-    _activeTitleBarColor =
-        appGroup.readEntry("activeBackground", globalGroup.readEntry("activeBackground", palette.color(QPalette::Active, QPalette::Highlight)));
-    _activeTitleBarTextColor =
-        appGroup.readEntry("activeForeground", globalGroup.readEntry("activeForeground", palette.color(QPalette::Active, QPalette::HighlightedText)));
-    _inactiveTitleBarColor =
-        appGroup.readEntry("inactiveBackground", globalGroup.readEntry("inactiveBackground", palette.color(QPalette::Disabled, QPalette::Highlight)));
-    _inactiveTitleBarTextColor =
-        appGroup.readEntry("inactiveForeground", globalGroup.readEntry("inactiveForeground", palette.color(QPalette::Disabled, QPalette::HighlightedText)));
+    _activeTitleBarColor = globalGroup.readEntry("activeBackground", palette.color(QPalette::Active, QPalette::Highlight));
+    _activeTitleBarTextColor = globalGroup.readEntry("activeForeground", palette.color(QPalette::Active, QPalette::HighlightedText));
+    _inactiveTitleBarColor = globalGroup.readEntry("inactiveBackground", palette.color(QPalette::Disabled, QPalette::Highlight));
+    _inactiveTitleBarTextColor = globalGroup.readEntry("inactiveForeground", palette.color(QPalette::Disabled, QPalette::HighlightedText));
+
+    if (const QString colorSchemePath = qApp->property("KDE_COLOR_SCHEME_PATH").toString(); !colorSchemePath.isEmpty()) {
+        KConfig config(colorSchemePath, KConfig::SimpleConfig);
+        KConfigGroup appGroup(config.group("WM"));
+        _activeTitleBarColor = appGroup.readEntry("activeBackground", _activeTitleBarColor);
+        _activeTitleBarTextColor = appGroup.readEntry("activeForeground", _activeTitleBarTextColor);
+        _inactiveTitleBarColor = appGroup.readEntry("inactiveBackground", _inactiveTitleBarColor);
+        _inactiveTitleBarTextColor = appGroup.readEntry("inactiveForeground", _inactiveTitleBarTextColor);
+    }
 }
 
 QColor transparentize(const QColor &color, qreal amount)
@@ -655,19 +661,6 @@ void Helper::renderButtonFrame(QPainter *painter,
         penBrush = KColorUtils::mix(color1, color2, penAnimation);
     }
 
-    // Gradient
-    if (isActiveWindow && !(flat || down || hovered || checked) && enabled) {
-        QLinearGradient bgGradient(frameRect.topLeft(), frameRect.bottomLeft());
-        bgGradient.setColorAt(0, KColorUtils::mix(bgBrush.color(), Qt::white, 0.03125));
-        bgGradient.setColorAt(0.5, bgBrush.color());
-        bgGradient.setColorAt(1, KColorUtils::mix(bgBrush.color(), Qt::black, 0.03125));
-        QLinearGradient penGradient(frameRect.topLeft(), frameRect.bottomLeft());
-        penGradient.setColorAt(0, KColorUtils::mix(penBrush.color(), Qt::white, 0.03125));
-        penGradient.setColorAt(1, KColorUtils::mix(penBrush.color(), Qt::black, 0.0625));
-        bgBrush = bgGradient;
-        penBrush = penGradient;
-    }
-
     // Shadow
     if (isActiveWindow && !(flat || down || checked) && enabled) {
         renderRoundedRectShadow(painter, shadowedRect, shadowColor(palette));
@@ -813,7 +806,7 @@ void Helper::renderCheckBoxBackground(QPainter *painter,
 
     case CheckPartial:
     case CheckOn:
-        painter->setBrush(transparent);
+        painter->setBrush(transparent.darker(sunken ? radioCheckSunkenDarkeningFactor : 100));
         painter->drawRoundedRect(frameRect, radius, radius);
         break;
 
@@ -966,7 +959,7 @@ void Helper::renderRadioButtonBackground(QPainter *painter,
         painter->drawEllipse(frameRect);
         break;
     case RadioOn:
-        painter->setBrush(transparent);
+        painter->setBrush(transparent.darker(sunken ? radioCheckSunkenDarkeningFactor : 100));
         painter->drawEllipse(frameRect);
         break;
     case RadioAnimated:
@@ -1319,7 +1312,7 @@ void Helper::renderTabBarTab(QPainter *painter,
             frameRect.adjust(1, 0, 0, 0);
         }
         const auto windowColor = palette.color(QPalette::Window);
-        bgBrush = windowColor.darker(windowColor.lightnessF() > 0.5 ? 120 : 160);
+        bgBrush = windowColor.darker(120);
         const auto hover = alphaColor(hoverColor(palette), 0.2);
         if (animated) {
             bgBrush = KColorUtils::mix(bgBrush, hover, animation);
